
################
gm3dh5 Reference
################

:Release: |version|
:Date: |today|

This reference manual details functions, modules, and objects
included in gm3dh5, describing what they are and what they do.
For learning how to use gm3dh5, see the :ref:`user`.

.. rubric:: Modules

.. toctree::
   :maxdepth: 2

   base
   exporters
